pub struct SnapshotStaleRule { /* private fields */ }Expand description
The snapshot is showing retained values, or follows an unexpectedly long gap (11.2, 7.5).
Two different problems with the same consequence: what is on screen is older than one sample interval. 4 requires a retained value to be shown with its age, and this rule is the summary of that state for the diagnostics panel.
Implementations
Sourceimpl SnapshotStaleRule
impl SnapshotStaleRule
Sourcepub const fn new(thresholds: Thresholds) -> Self
pub const fn new(thresholds: Thresholds) -> Self
Builds the rule from sanitized thresholds.